'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.RouteServiceProvider = void 0;
const goodies_1 = require("@supercharge/goodies");
const support_1 = require("@supercharge/support");
class RouteServiceProvider extends support_1.ServiceProvider {
    constructor() {
        super(...arguments);
        this.loadRoutesCallbacks = [];
    }
    /**
     * Register application services to the container.
     */
    register() {
        this.booted(() => {
            this.runRouteLoadingCallbacks();
        });
    }
    /**
     * Run the registered route-loading callbacks.
     */
    runRouteLoadingCallbacks() {
        this.loadRoutesCallbacks.forEach(callback => {
            callback();
        });
    }
    /**
     * Load the routes file from the given `path`.
     *
     * @param callback
     *
     * @returns {this}
     */
    loadRoutesFrom(path) {
        return this.loadRoutesUsing(() => {
            require(path);
        });
    }
    /**
     * Register a callback that will be used to load the application’s routes.
     *
     * @param callback
     *
     * @returns {this}
     */
    loadRoutesUsing(callback) {
        return (0, goodies_1.tap)(this, () => {
            this.loadRoutesCallbacks.push(callback);
        });
    }
}
exports.RouteServiceProvider = RouteServiceProvider;
